<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_PT">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>novo</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>copia de</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Todos os turnos</numerusform>
            <numerusform>Cada %1 turnos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit schemes</source>
        <translation>Editar esquemas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Esquema de armas inválido</translation>
    </message>
    <message>
        <source>Edit weapons</source>
        <translation>Editar armas</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>Com esta opção activada o esquema de jogo irá automaticamente seleccionar uma arma</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 foi removido da tua Ignore List</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 foi adicionado à tua Ignore List</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 foi removido da tua lista de amigos</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 foi adicionado à tua lista de amigos</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation type="obsolete">novo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Não foi possível iniciar o servidor</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Não foi possível gravar no ficheiro %1</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Seleccione uma gravação da lista acima</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>EquipaPorOmissão</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Ficheiro de demo Hedgewars</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Ficheiro de jogo Hedgewars</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>pt_PT.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Não foi possível abrir o ficheiro %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Caverna</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Invulgar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Túneis pequenos</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Túneis medios</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Túneis grandes</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Ilhas flutuantes pequenas</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Ilhas flutuantes médias</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Ilhas flutuantes grandes</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>Semente</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Definir</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>O host não foi encontrado. Verifique o nome do host e as definições de porta.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Conexão rejeitada</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Sala destruída</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Motivo de saída: </translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Foi expulso</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">O nome de utilizador %1 está
registado em Hedgewars.org
Por favor digite a sua palavra passe
ou escolha outro nome de utilizador:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 juntou-se à sala</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 juntou-se</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 saíu (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 saíu</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>O nome de utilizador %1 está
registado em Hedgewars.org
Por favor digite a sua palavra passe ou escolha
outro nome de utilizador no menu de configuração:</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf retornou um erro ao renderizar o texto, muito provavelmente está relacionado com o bug no freetype2. É recomendado actualizar a sua lib freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Mensagem do servidor:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Definir mensagem</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Limpar a cache das contas</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Adquirir informação</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Mensagem do servidor para a versão mais recente:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Mensagem do servidor para versões anteriores:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Número do protocolo da versão mais recente:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Pré-visualizar o MOTD</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Gravar modificações</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>A ligar...</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>Carregar mapa desenhado</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation>Mapas Desenhados (*.hwmap);;Todos os ficheiros (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>Gravar mapa desenhado</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;O título de melhor tiro foi para &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; pontos de dano.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;O extreminador da ronda foi &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; morto num unico turno.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;O extreminador da ronda foi &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; mortes num unico turno.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Apenas &lt;b&gt;%1&lt;/b&gt; ouriço perdeu a vida durante esta ronda.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Um total de &lt;b&gt;%1&lt;/b&gt; ouriços perderam a vida durante esta ronda.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Gráfico de vida</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Ranking</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>O título de melhor tiro foi para &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; pontos de dano.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>O extreminador da ronda foi &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; morto num unico turno.</numerusform>
            <numerusform>O extreminador da ronda foi &lt;b&gt;%1&lt;/b&gt; com &lt;b&gt;%2&lt;/b&gt; mortes num unico turno.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Apenas &lt;b&gt;%1&lt;/b&gt; ouriço perdeu a vida durante esta ronda.</numerusform>
            <numerusform>Um total de &lt;b&gt;%1&lt;/b&gt; ouriços perderam a vida durante esta ronda.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 morto)</numerusform>
            <numerusform>(%1 mortos)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; axou que seria divertido atacar a sua própria equipa fazendo &lt;b&gt;%2&lt;/b&gt; ponto de dano.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; axou que seria divertido atacar a sua própria equipa fazendo &lt;b&gt;%2&lt;/b&gt; pontos de dano.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; matou &lt;b&gt;%2&lt;/b&gt; ouriço da sua própria equipa.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; matou &lt;b&gt;%2&lt;/b&gt; ouriços da sua própria equipa.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; estava tão intimidado que passou &lt;b&gt;%2&lt;/b&gt; turno.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; estava tão intimidado que passou &lt;b&gt;%2&lt;/b&gt; turnos.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Jogo local (Joga Hedgewars apenas com este computador)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Jogo em rede (Joga em rede ou na internet)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Simplesmente selecciona a mesma cor de outro jogador para jogarem em equipa. Continuas a ter total controlo dos teus ouriços, mas ganham ou perdem juntos.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Algumas armas podem não fazer muito dano, mas em ocasiões especificas podem-se demonstrar bastante mais letais. Experimenta usar a Desert Eagle para empurrar varios ouriços para a água.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Se não tens a certeza do que fazer a seguir não desperdiçes munições, passa o turno. Mas não desperdices muito tempo, a Morte Súbita aproxima-se.</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Se não queres que outros usem o teu nome de utilizador preferido no servidor oficial, regista-o em http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>Estás cansado do modo de jogo habitual? Experimenta uma das missões - existem várias por onde escolher, e todas com objectivos um pouco diferentes.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>Por defeito, o ultimo jogo em que participaste é sempre gravado como &apos;demo&apos;. Selecciona &apos;Jogo Local&apos; e aí a opção &apos;Demos&apos; no canto inferior direito para os gerir ou reproduzir.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>O Hedgewars é Open Source e Freeware, desenvolvido nos tempos livres. Se tiveres algum problema pergunta nos fóruns, mas por favor não esperes suporte 24/7!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>O Hedgewars é Open Source e Freeware, desenvolvido nos tempos livres. Se gostares do jogo podes contribuir com uma pequena doação ou o teu próprio trabalho!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>O Hedgewars é Open Source e Freeware, desenvolvido nos tempos livres. Partilha-o com a família e amigos como quiseres!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>De tempos a tempos realizam-se torneios oficiais. Todos estes eventos são anunciados em http://www.hedgewars.org/ com alguns dias de antecedência.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>O Hedgewars está disponível em vários idiomas. Se a tradução do teu idioma está desactualizada ou em falta, não hesites em contactar-nos!</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>O Hedgewars está disponível para vários sistemas operativos incluindo Microsoft Windows, Mac OS X e Linux.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Lembra-te que tens sempre a opção de poder jogar na tua rede local ou online. Não estás restrito ao modo de Jogo Local.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>Lembra-te de fazer pequenos intervalos durante sessões de jogo prolongadas.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Se a tua placa gráfica não é capaz de fornecer aceleração por hardware para OpenGL experimenta activar o modo de baixa qualidade para melhorar a performance.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Estamos abertos a sugestões e críticas construtivas. Se há algo que não gostas em particular ou tiveste uma boa ideia, deixa-nos saber!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Especialmente durante partidas online é importante ser educado. Lembra-te que podem haver menores a jogar com ou contra ti!</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Modos de jogo especiais como &apos;Vampirismo&apos; ou &apos;Karma&apos; permitem-te desenvolver tácticas completamente novas! Experimenta-os num jogo personalizado!</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation>A versão do Hedgewars para Windows suporta Xfire. Não te esqueças de adicionar o Hedgewars à tua lista de jogos para que os teus amigos te possam ver a jogar.</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>Não deves instalar o Hedgewars em computadores que não te pertençam (escola, universidade, trabalho, etc.). Por favor contacta o responsável caso o pretendas fazer.</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>O Hedgewars é perfeito para pequenos jogos durante intervalos. Tem apenas a certeza que não adicionas muitos ouriços ou usas um mapa muito grande. Reduzir o tempo e pontos de vida pode ajudar também.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Nenhum ouriço foi mal tratado durante a produção deste jogo.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>O Hedgewars é Open Source e Freeware desenvolvido durante o tempo livre. Se alguem te vendeu o jogo, tente obter o reembolso!</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Conecta um ou mais comandos antes de lançar o jogo para que seja possível configura-los com as tuas equipas.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Cria uma conta em http://www.hedgewars.org/ para prevenir que outros usem o teu nome de utilizador favorito no servidor oficial.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Se a tua placa gráfica se está a demonstrar incapaz de fornecer aceleração gráfica em OpenGL, experimenta actualizar os drivers da mesma.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>Existem três diferentes tipos de salto. Pressiona [salto alto] duas vezes para fazer um salto muito alto para trás.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>Com medo de cair de um penhasco? Deixa o [botão de precisão] pressionado e vira-te para a [direita] ou [esquerda] sem sair do sitio.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Algumas armas requerem estratégias especiais ou imensa prática, por isso não desistas imediatamente dessa ferramenta em particular se falhares o alvo.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>A maiora das armas deixa de funcionar se tocarem na água. A Abelha Teleguiada e o Bolo são excepções a esta regra.</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>O Limburger Venho causa apenas uma pequena explosão. No entanto a pequena nuvem malcheirosa, afectada pelo vento, pode envenenar vários ouriços de uma vez.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>O Piano é o ataque aéreo que mais potencial dano causa. No entanto uma enorme desvantagem, é necessario sacrificar um ouriço para o utilizar.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation>A Abelha Teleguiada é uma arma difícil de usar. O grau a que pode virar depende da sua velocidade, por isso tenta não a usar com o poder máximo.</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>As Minas Pegajosas são a arma ideal para com pequenas explosões em cadeia empurrar ouriços para situações terríveis... ou para a água.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>O melhor local para usar o Martelo é em pontes ou vigas. Os ouriços atingidos nestes locais vão simplesmente furar pelo chão.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Se ficares preso atrás de um ouriço inimigo utiliza o Martelo para te libertares sem ser necessário levar dano de uma explosão.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>A distancia máxima que o Bolo é capaz de alcançar depende do terreno que tenha de ultrapassar. Podes também utilizar [ataque] para o detonar a qualquer altura.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>Embora o Lança-chamas seja uma arma, pode também ser usado para escavar túneis.</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation>Utiliza o Coquetail Molotov para temporariamente impedir outros ouriços de passar por áreas no terreno como túneis e plataformas.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>Gostavas de saber quem está por traz deste jogo? Clica no logótipo do Hedgewars no menu inicial para aceder aos créditos.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>Gostas do Hedgewars? Torna-te fã no %1 ou segue-nos pelo %2!</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>Está à vontade para desenhar as tuas próprias sepulturas, chapéus, bandeiras ou mesmo mapas e temas! Tem em nota que vai ser necessário partilha-los algures para que os consigas usar online.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>Gostavas poder usar um chapéu em particular que ainda não existe? Faz uma pequena doação para este projecto e recebe um chapéu exclusivo à tua escolha!</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Mantém os drivers da placa gráfica actualizados de forma a evitar problemas com o jogo.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Podes encontrar os ficheiros de configuração do Hedgewars em &quot;Documentos\Hedgewars&quot;. Cria cópias de segurança ou leva os ficheiros contigo, apenas não os edites.</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>É possivel associar os ficheiros relacionados com o Hedgewars (partidas e demonstrações) directamente com o jogo para que seja possivel lançalos directamente do teu explorador de ficheiros ou internet favorito.</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>Gostavas de poupar algumas cordas? Solta a corda enquanto no ar e dispara-a novamente. Desde que não toques no solo podes reutilizar a usar a mesma corda quantas vezes quiseres!</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Podes encontrar os ficheiros de configuração do Hedgewars em &quot;Library/Application Support/Hedgewars&quot; dentro da tua &quot;Pasta Pessoal&quot;. Cria cópias de segurança ou leva os ficheiros contigo, mas não os edites manualmente.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Podes encontrar os ficheiros de configuração do Hedgewars em &quot;.hedgewars&quot; dentro da tua &quot;Pasta Pessoal&quot;. Cria cópias de segurança ou leva os ficheiros contigo, mas não os edites manualmente.</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Seleccione um servidor da lista acima</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Controlo</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Jogo em LAN</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Servidor oficial</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nova equipa</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Editar equipa</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Apagar equipa</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Novo esquema de armas</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Editar esquema de armas</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Apagar esquema de armas</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Não é possível editar equipas do menu de selecção de equipa. Volte ao menu principal se pretender adicionar, editar ou apagar equipas.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>Novo esquema</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>Editar esquema</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>Apagar esquema</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>Novo esquema de armas</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>Editar esquema de armas</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>Apagar esquema de armas</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Insira um novo nome para o ficheiro:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Não foi possível renomear para</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Não é possível eliminar o ficheiro</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Por favor seleccione uma gravação da lista</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Criar</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Recursos de administrador</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Nome da Sala:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Este jogo está ainda na entrada.
Pode-se juntar e jogar assim que o jogo começe.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Este jogo está em progresso.
Pode-se juntar e observar, mas vai ter de esperar que o jogo termine para poder jogar.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 é o anfitrião. Ele pode ajustar as configurações e começar o jogo.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Mapa Aleatório</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>É possivel jogar em mapas pré-criados ou aleatórios.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>O Esquema de Jogo define as configurações gerais e preferências como Tempo da Ronda, Morte súbita ou Vampirismo.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>O Esquema de Armas define que armas estão disponíveis e a quantidade de munições.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Apenas %1 cliente esta conectado a esta sala.</numerusform>
            <numerusform>Um total de %1 clientes estão conectados a esta sala.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Apenas %1 equipa esta a participar nesta sala.</numerusform>
            <numerusform>Existem %1 equipas a participar nesta sala.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Insira o nome da sala</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Seleccione uma sala da lista</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Labirinto Aleatório</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Regras</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Armas:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Pesquisa:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Atenção</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>O jogo a que te estas a tentar juntar já começou.
Desejas juntar-te ao jogo de qualquer maneira?</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Defende o teu forte e destrói os inimigos, duas cores de equipa no máximo!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>As equipas começarão em lados opostos do terreno, duas cores de equipa no máximo!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>O terreno não pode ser destruído!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Adiciona uma borda indestrutível à volta do terreno</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Baixa gravidade</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Mira assistida por laser</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Todos os ouriços têm um campo de forças pessoal</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Adiciona minas aleatoriamente</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Converte 80% do dano realizado em vida</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Partilhe o sofrimento dos inimigos, e os danos</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Os teus ouriços serão impossibilidados de se mexer, testa as tuas capacidades no modo artilharia</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatório</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>A ordem de jogo será aleatória em vez de seguir a ordem do quadro.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Jogar com um Rei. Se ele morrer, o teu lado morre.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Posiciona os ouriços no mapa alternadamente antes do jogo começar.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>As armas são partilhadas entre todas as equipas da mesma cor.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Desactivar vigas em mapas gerados aleatoriamente.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Não adicionar objectos de terreno ao gerar mapas aleatórios.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>O computador ressuscita ao morrer.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>Todos os ouriços (vivos) são completamente restaurados no final do turn</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Atacar não faz o turno terminar.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>O armamento é redefinido para os valores iniciais todos os turnos.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>Cada ouriço tem as suas próprias armas. Não são partilhadas com a equipa.</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>Não vais ter de te preocupar mais com o vento.</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>O vento afecta quase tudo.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Predefinido</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Jogo simples (jogo rápido contra o computador, as definições serão escolhidas para si)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multi Jogador (jogo estratégico contra amigos ou equipas IA)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Modo de Treino (pratica as tuas capacidades numa variedade de missões de treino). EM DESENVOLVIMENTO</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demos (ver demos gravados)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Carregar (carrega um jogo salvo previamente)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>Modo Campanha (...) EM DESENVOLVIMENTO</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Expulsar</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Restringir entradas</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Restringir adição de equipas</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Banir</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Seguir</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Adicionar amigo</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Remover ignorar</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Remover amigo</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Verificar por actualizações no arranque</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã completo</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Menu em ecrã completo</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Activar som</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Activar música</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Mostrar FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Forma alternativa de mostrar o dano</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Adicionar data e hora ao nome do ficheiro de gravação</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Qualidade reduzida</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Mostrar a ajuda no menu das armas</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Activar os sons no frontend</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Activar a musica no frontend</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Efeitos no frontend</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>mapa gerado...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Humano</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nível</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Definições por omissão)</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Missão</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>labirinto gerado...</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Comunidade</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Qualquer</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>No lobby</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>Em progresso</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Predefinido</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>mapa desenhado à mão...</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Membros de equipa</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Forte</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Associação de teclas</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipas</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Armas</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Opções de Áudio/Gráficos</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Jogo em rede</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Equipas a jogar</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Modificadores de jogo</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Definições básicas</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Configurações de Equipa</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>Esquemas e Armamento</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Tempo das minas</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Minas</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Este programa é distribuído sob a GNU General Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Programadores:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Arte:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Som:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Tradutores:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Agradecimentos especiais:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Nick de rede</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Limite de FPS</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Nome do servidor:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Porta do servidor:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Volume de som inicial</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modificador de dano</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Tempo por turno</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Vida inicial</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Tempo até Morte Súbita</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Nome do esquema:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Queda de caixas</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Esquema de jogo</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% Minas Falsas</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Túmulo</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Bandeira</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Reinicie o jogo para aplicar as alterações</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Explosivos</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Dica: </translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% de Caixas de Vida</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Vida por Caixa</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Súbida da água durante Morte Súbita</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Vida perdida durante Morte Súbita</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% Comprimento da Corda</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation>Jogabilidade</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>sem nome</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Conexão com o servidor perdida</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Não foi possível abrir o directório:
%1
Por favor verifique a sua instalação</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Não é possível editar o esquema de armas predefinido</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Não é possível eliminar o esquema de armas predefinido</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Deseja mesmo eliminar este esquema de armas?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Não é possivel sobrescrever o esquema de armas por omissão &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Os ficheiros foram associados com sucesso.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>Não foi possivel associar os ficheiros.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipas</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>Deseja mesmo apagar esta equipa?</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>Esquemas</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>Não é possível eliminar o esquema por omisão &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>Deseja mesmo apagar este esquema de jogo?</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>Não é possível eliminar o esquema de armas por omisão &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Não foi possível criar o directório %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Por favor insira o seu nome de utilizador</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>predefinido</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Iniciar servidor</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Especificar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Começar!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Reproduzir demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Preparado</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Equipa aleatória</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Associar com as extensões dos ficheiros</translation>
    </message>
    <message>
        <source>more</source>
        <translation>mais</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Nome da Sala</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>E</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Anfitrião</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Regras</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Esquema de armas</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Probabilidades</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Caixas de armas</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Atrasos</translation>
    </message>
    <message>
        <source>new</source>
        <translation>novo</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>copia de</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Não foi possível iniciar o servidor: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Não foi possível executar o motor: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampirismo</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artilharia</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Modo Forte</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Separar Equipas</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Terreno Sólido</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Adicionar Borda</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Baixa Gravidade</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Mira laser</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Invulnerabilidade</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Adicionar minas</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Ordem Aleatória</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Rei</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Posicionar Ouriços</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Clãs Partilham Armamento</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Desactivar Vigas</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Desactivar Objectos no Terreno</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>Modo de Sobrevivência</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Restaurar a Vida</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Ataques Ilimitados</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Restaurar o Armamento</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Armamento Por Ouriço</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>Desactivar Vento</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>Mais Vento</translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>cima</translation>
    </message>
    <message>
        <source>left</source>
        <translation>esquerda</translation>
    </message>
    <message>
        <source>right</source>
        <translation>direita</translation>
    </message>
    <message>
        <source>down</source>
        <translation>baixo</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>atacar</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>pontaria rigorosa</translation>
    </message>
    <message>
        <source>put</source>
        <translation>colocar</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>trocar</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>encontrar ouriço</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>menu de armas</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>temporizador 1 seg</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>temporizador 2 seg</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>temporizador 3 seg</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>temporizador 4 seg</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>temporizador 5 seg</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>mensagens</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>histórico de mensagens</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pausa</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>confirmação</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>diminuir volume</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>aumentar volume</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>alterar modo</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>capturar</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>informação dos
ouriços</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>sair</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>aumentar zoom</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>diminuir zoom</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reiniciar zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>salto grande</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>salto alto</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>slot 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Controlos basicos</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Controlos de armas</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Controlos de camara e cursor</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Movimentar os teus ouriços e apontar:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Ultrapassar fendas e obstaculos saltando:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Disparar a arma currentemente seleccionada ou utilizar um utilitario:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Seleccionar uma arma ou escolher um alvo com o cursor:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Trocar de ouriço currentemente seleccionado (se possivel):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Apanhar armas ou utilitarios:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Escolher o tempo nas bombas e outras armas temporizadas:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Mover a camara para o ouriço currentemente activo:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Mover o cursor ou camara sem usar o rato:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Modificar o nível de zoom da camara:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Escrever para a tua equipa ou todos os participantes:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pausar, continuar ou abandonar o jogo:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Modificar o volume durante o jogo:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Alterar para modo de ecrã inteiro:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Tirar um screenshot:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Alterar as etiquetas acima dos ouriços:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Eixo</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Cima)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Baixo)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Chapéu</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Esquerda)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Direita)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Botão</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Teclado</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Rato: Botão esquerdo</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Rato: Botão do meio</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Rato: Botão direito</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Rato: Roda para cima</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Rato: Roda para baixo</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Retrocesso (backspace)</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulação</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Espaço</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Igual</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Cima</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page uo</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Shift direito</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Shift esquerdo</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Ctrl direito</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Ctrl esquerdo</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Alt direito</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Alt esquerdo</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Meta direito</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Meta esquerdo</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Back</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Stick esquerdo</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Stick direito</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Stick esquerdo (Direita)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Stick esquerdo (Esquerda)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Stick esquerdo (Baixo)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Stick esquerdo (Cima)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Gatilho esquerdo</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Gatilho direito</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Stick direito (Baixo)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Stick direito (Cima)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Stick direito (Direita)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Stick direito (Esquerda)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
</context>
</TS>
